@@ -1,6 +1,6 @@
 /* common.h
    Shared header file for the GNOMAD package
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2007 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -51,10 +51,30 @@ Boston, MA 02111-1307, USA.
 /* The GTK library */
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-/* Using Windows implies diabling threading */
-#ifdef G_OS_WIN32
-#define DISABLE_THREADING
+
+/* Macros lacking in GTK+ */
+#ifdef G_GUINT32_FORMAT
+#define PRIguint32 G_GUINT32_FORMAT
+#define PRIguint64 G_GUINT64_FORMAT
+#else
+/* Retrieve C99 format macros */
+#if HAVE_INTTYPES_H
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
+#define PRIguint32 PRIu32
+#define PRIguint64 PRIu64
+#else
+#define PRIguint32 "u"
+#define PRIguint64 "Lu"
 #endif
+#endif
+
+#define GUINT32_TO_GPOINTER GUINT_TO_POINTER
+#define GPOINTER_TO_GUINT32 GPOINTER_TO_UINT
+
+/* Directory colors */
+#define GNOMAD_DIRECTORY_FILE_ENTRY_COLOR    "black"
+#define GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR  "blue"
 
 /* Globally useful structures */
 
@@ -102,9 +122,6 @@ transfer_widgets_t transfer_widgets;
 data_widgets_t data_widgets;
 playlist_widgets_t playlist_widgets;
 
-/* The blue color is good to have global as it is throughly reused */
-GdkColor darkblue;
-
 /* Global progress bar - not so good but... */
 GtkWidget *progress_bar;
 
@@ -126,4 +143,9 @@ gint gnomad_debug;
 GCallback dispose_of_dialog_window(GtkButton * button, gpointer data);
 #endif
 
+/* THIS PROBABLY BELONGS IN A DIFFERENT HEADER.
+ * THIS IS THE ONLY EXTERNAL FUNCTION DEFINED IN gnomad2.c (other than main).
+ */
+extern void scan_jukebox(gpointer data);
+
 #endif
