@@ -41,7 +41,7 @@ static GCallback data_from_jukebox_to_hd (GtkButton *button,
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
     destroy_metalist(metalist);
-    return;
+    return NULL;
   }
 
   if (metalist != NULL) {
@@ -98,6 +98,7 @@ static GCallback data_from_jukebox_to_hd (GtkButton *button,
     cancel_jukebox_operation = FALSE;
     g_thread_create(jb2hd_data_thread,(gpointer) jb2hd_data_thread_args, FALSE, NULL);
   }
+  return NULL;
 }
 
 
@@ -112,7 +113,7 @@ static GCallback data_from_hd_to_jukebox()
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
     destroy_metalist(metalist);
-    return;
+    return NULL;
   }
   
   if (metalist != NULL) {
@@ -169,6 +170,7 @@ static GCallback data_from_hd_to_jukebox()
     cancel_jukebox_operation = FALSE;
     g_thread_create(hd2jb_data_thread,(gpointer) hd2jb_data_thread_args, FALSE, NULL);
   }
+  return NULL;
 }
 
 static void add_to_history (gchar *string)
@@ -201,6 +203,7 @@ static void add_to_history (gchar *string)
 static GCallback hdmenu_rescan_response(gpointer data)
 {
   fill_in_dir(HDDATA_LIST, get_current_dir());
+  return NULL;
 }
 
 
@@ -208,6 +211,7 @@ static GCallback hdmenu_rescan_response(gpointer data)
 static GCallback hdmenu_transfer_response(gpointer data)
 {
   data_from_hd_to_jukebox(NULL, NULL);
+  return NULL;
 }
 
 /* Response to the "delete" call from the harddisk popup menu */
@@ -221,6 +225,7 @@ static GCallback hdmenu_delete_response(gpointer data)
     destroy_metalist(metalist);
     // fill_in_dir(HDDATA_LIST, get_current_dir());
   }
+  return NULL;
 }
 
 /* Handles descending into a directory */
@@ -254,7 +259,6 @@ static void go_down()
 
 static void go_down_jukebox()
 {
-  gchar *path;
   metadata_t *meta;
 
   meta = get_first_metadata_from_selection(JBDATA_LIST);
@@ -317,6 +321,7 @@ static GCallback hdlist_keyevent (GtkWidget    *widget,
 static GCallback jbmenu_rescan_response(gpointer data)
 {
   scan_jukebox(NULL);
+  return NULL;
 }
 
 
@@ -324,6 +329,7 @@ static GCallback jbmenu_rescan_response(gpointer data)
 static GCallback jbmenu_transfer_response(gpointer data)
 {
   data_from_jukebox_to_hd(NULL, NULL);
+  return NULL;
 }
 
 
@@ -338,6 +344,7 @@ static GCallback create_new_folder_ok_button (GtkButton *button,
   g_print("Creating folder \"%s\"...\n", foldername);
   jukebox_create_folder(foldername);
   g_free(foldername);
+  return NULL;
 }
 
 
@@ -404,6 +411,7 @@ static GCallback jbmenu_create_folder_response(gpointer data)
 		   G_OBJECT (new_folder_dialog));
 
   gtk_widget_show_all(new_folder_dialog);
+  return NULL;
 }
 
 
@@ -417,6 +425,7 @@ static GCallback jbmenu_delete_response(gpointer data)
     remove_selected(JBDATA_LIST);
     destroy_metalist(metalist);
   }
+  return NULL;
 }
 
 
@@ -472,13 +481,13 @@ static void cell_data_func (GtkTreeViewColumn *tree_column,
   metadata_t *meta = get_data_metadata_from_model(model, iter);
   if (meta->size == 0) {
     g_object_set(G_OBJECT(cell),
-		 "foreground", "blue", 
+		 "foreground", GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR, 
 		 "weight", "bold",
 		 "underline", TRUE,
 		 NULL);
   } else {
     g_object_set(G_OBJECT(cell),
-		 "foreground", "black", 
+		 "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
 		 "weight", NULL,
 		 "underline", FALSE,
 		 NULL);
@@ -490,7 +499,6 @@ static void cell_data_func (GtkTreeViewColumn *tree_column,
 static GtkWidget *create_listview(GtkListStore *liststore)
 {
   GtkWidget *listview;
-  GtkTreeIter listiter;
   GtkCellRenderer *dirtextrenderer;
   GtkCellRenderer *textrenderer;
   GtkTreeViewColumn *view;
@@ -549,7 +557,6 @@ GtkWidget *create_data_widgets(void)
 {
   GtkWidget *popupmenu, *popupmenu_item;
   GtkWidget *button;
-  GtkWidget *vbox, *hbox;
   GtkWidget *leftbox;
   GtkWidget *panel;
   GtkWidget *transfer_button_vbox;
@@ -565,7 +572,6 @@ GtkWidget *create_data_widgets(void)
   GtkWidget *jblistview;
   GtkTreeSelection *hdlistselection;
   GtkTreeSelection *jblistselection;
-  gint i;
 
   data_widgets.history = NULL;
   /* Just add something to the history... */
