@@ -27,6 +27,8 @@ Boston, MA 02111-1307, USA.
 #include "jukebox.h"
 #include "xfer.h"
 #include "util.h"
+#include "id3read.h"
+#include "prefs.h"
 
 static listtype_t target;
 static GtkWidget *edit_dialog;
@@ -45,17 +47,18 @@ static gchar *folder;
 static gchar *protect;
 
 /* Response to DELETE event (window destruction) */
-static gint delete(GtkWidget *widget,
-		   GtkWidget *event,
-		   gpointer   data)
-{
-  if (metalist != NULL) {
-    destroy_metalist(metalist);
-  }
-  metalist = NULL;
-  gtk_grab_remove(edit_dialog);
-  return(FALSE);
-}
+// Not actually used
+//static gint delete(GtkWidget *widget,
+//		   GtkWidget *event,
+//		   gpointer   data)
+//{
+//  if (metalist != NULL) {
+//    destroy_metalist(metalist);
+//  }
+//  metalist = NULL;
+//  gtk_grab_remove(edit_dialog);
+//  return(FALSE);
+//}
 
 static gchar *ret_nonull(gchar *retval)
 {
@@ -82,19 +85,19 @@ static gchar *metalist_get_column(GList *metalist, gint column)
       return ret_nonull(meta->album);
     case TRACKLIST_YEAR_COLUMN:
       /* Convert to string and return */
-      return g_strdup_printf("%lu",meta->year);
+      return g_strdup_printf("%" PRIguint32,meta->year);
     case TRACKLIST_GENRE_COLUMN:
       return ret_nonull(meta->genre);
     case TRACKLIST_LENGTH_COLUMN:
       return g_strdup(meta->length);
     case TRACKLIST_SIZE_COLUMN:
       /* Convert to string and return */
-      return g_strdup_printf("%lu",meta->size);
+      return g_strdup_printf("%lu", meta->size);
     case TRACKLIST_CODEC_COLUMN:
       return ret_nonull(meta->codec);
     case TRACKLIST_TRACKNO_COLUMN:
       /* Convert to string and return */
-      return g_strdup_printf("%lu",meta->trackno);
+      return g_strdup_printf("%" PRIguint32,meta->trackno);
     case TRACKLIST_PROTECTED_COLUMN:
       return g_strdup_printf("%s", meta->protect ? _("YES") : _("NO"));
     case TRACKLIST_FILENAME_COLUMN:
@@ -190,9 +193,9 @@ static void edit_ok_click ( GtkButton *button,
     }
     if (trackno != NULL &&
 	strlen(trackno) &&
-	string_to_guint(trackno) != meta->trackno) {
+	string_to_guint32(trackno) != meta->trackno) {
       changed = TRUE;
-      newmeta->trackno = string_to_guint(trackno);
+      newmeta->trackno = string_to_guint32(trackno);
     }
     if (origfname != NULL &&
 	strlen(origfname) &&
@@ -210,14 +213,13 @@ static void edit_ok_click ( GtkButton *button,
     }
     if (year != NULL &&
 	strlen(year) &&
-	string_to_guint(year) != meta->year) {
+	string_to_guint32(year) != meta->year) {
       changed = TRUE;
-      newmeta->year = string_to_guint(year);
+      newmeta->year = string_to_guint32(year);
     }
     if (changed) {
       /* Write the new tag */
       gchar tmp[512];
-      gint i, j;
     
       /* First is artist, second is title */
       sprintf(tmp, _("Updating metadata on %s - %s"), newmeta->artist, newmeta->title);
