@@ -30,6 +30,10 @@ Boston, MA 02111-1307, USA.
 #if !GTK_CHECK_VERSION(2,4,0)
 #include <libgnomeui/libgnomeui.h>
 #endif
+#if GLIB_CHECK_VERSION(2,6,0)
+#include <glib.h>
+#include <glib/gstdio.h>
+#endif
 
 /* Extra includes used by this file only */
 
@@ -228,7 +232,13 @@ gchar *filename_fromutf8(const gchar * const instr)
   gchar *tmp;
   
   if (get_prefs_force_8859()) {
-    tmp = g_convert(instr,-1,"ISO-8859-1","UTF-8",NULL,NULL,NULL);
+    /* FIXME utf8 conversion
+	 * when the system fails to convert the fname, ask the user
+	 * but until the dialog box is created, don't crash, use
+	 * "?" for fname characters that can't be converted instead of:
+	 * tmp = g_convert(instr,-1,"ISO-8859-1","UTF-8",NULL,NULL,NULL);
+	 */
+	tmp = g_convert_with_fallback(instr,-1,"ISO-8859-1","UTF-8","?",NULL,NULL,NULL);
   } else {
     tmp = g_filename_from_utf8(instr,-1,NULL,NULL,NULL);
   }
@@ -261,6 +271,9 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
   /* Directories: no full path, just dirname; size 0 */
   filelist = NULL;
   tmppath = filename_fromutf8(base_path);
+  if (gnomad_debug != 0) {
+    g_print("Getting directory listing for: %s\n", base_path);
+  }
   dirp = opendir(tmppath);
   if (!dirp){
     if (gnomad_debug != 0) {
@@ -277,10 +290,14 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
       int is_dir;
       int is_file;
 
-      strncpy(path_buffer, tmppath, 512);
-      strcat(path_buffer, G_DIR_SEPARATOR_S);
-      strcat(path_buffer, dir_entry->d_name);
-      if (g_stat(path_buffer, &entry_status)) {
+      strncpy(path_buffer, tmppath, sizeof(path_buffer)-1);
+      path_buffer[sizeof(path_buffer)-1] = '\0';
+      strncat(path_buffer, G_DIR_SEPARATOR_S, sizeof(path_buffer)-1-strlen(path_buffer));
+      strncat(path_buffer, dir_entry->d_name, sizeof(path_buffer)-1-strlen(path_buffer));
+      if (gnomad_debug != 0) {
+	g_print("Examining dir path: %s\n", path_buffer);
+      }
+      if (stat(path_buffer, &entry_status)) {
 	if (gnomad_debug != 0) {
 	  g_print("Failed to read file status for %s.\n", path_buffer);
 	}
@@ -307,7 +324,6 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
       } else if (is_file) {
 	char tmp_codec[4];
 	char *tmp;
-	int i;
 
 	if (!anyfile) {
 	  /* Must be more atleast one byte */
@@ -324,6 +340,8 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
 	      g_ascii_strcasecmp(tmp,"wma")
 #ifdef HAVE_LIBMTP
 	      // Additional music codecs supported by libmtp
+	      // TODO: base this on the list of filetypes actually
+	      // supported by a particular device, if one is connected.
 	      &&
 	      g_ascii_strcasecmp(tmp,"ogg") &&
 	      g_ascii_strcasecmp(tmp,"flac") &&
@@ -348,6 +366,7 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
       }
 #ifndef G_OS_WIN32
       filename = g_strdup(path_buffer);
+      // g_printf("strdup(%s)=%s\n", path_buffer, filename);
 #else
       // On Windows we need to convert into UTF-8 since
       // this does not use the stdio wrappers properly.
@@ -370,7 +389,8 @@ static GList *get_metadata_for_dirlist(GList *inlist,
 {
   GList *metalist = NULL;
   GList *filelist;
-  guint nofiles, currentfile;
+  guint nofiles = 0;  /* initialize to shut up GCC */
+  guint currentfile;
   gboolean use_dialog = FALSE;
   gboolean cancelled = FALSE;
 
@@ -391,10 +411,7 @@ static GList *get_metadata_for_dirlist(GList *inlist,
   while ((filelist != NULL) && !cancelled) {
     metadata_t *meta;
     gchar *path;
-    gchar *data;
     gchar *tmp;
-    guint size;
-    gint i;
     gchar fileext[5];
         
     meta = new_metadata_t();
@@ -596,7 +613,7 @@ GList *get_metadata_dir(listtype_t listtype,
   return metalist;
 }
 
-gpointer dirfill_thread(gpointer thread_args)
+static gpointer dirfill_thread(gpointer thread_args)
 {
   dirfill_thread_arg_t *args = (dirfill_thread_arg_t *) thread_args;
   GList *metalist;
@@ -619,6 +636,7 @@ gpointer dirfill_thread(gpointer thread_args)
   g_idle_add((GSourceFunc) gtk_widget_destroy, args->dialog);
   g_free(args->path);
   g_free(args);
+  return NULL;
 }
 
 /**
@@ -751,7 +769,7 @@ void change_directory(gchar *dir)
 gint remove_dir_contents(gchar *dir)
 {
   GDir * current_dir;
-  gchar * file = NULL;
+  const gchar * file = NULL;
   gchar * current_file = NULL;
   gint c = 0;
 
