@@ -30,6 +30,7 @@ Boston, MA 02111-1307, USA.
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus.h>
+#include <dbus/dbus-glib-lowlevel.h>
 #endif
 
 /* This one should be global really */
@@ -231,7 +232,6 @@ static void about_box(gpointer data)
 			    "Richard A. Low - initial MTP work and libmtp",
 			    NULL};
   const gchar *copystring = "Copyright (C) 2006 Linus Walleij";
-  const gchar *thanks[] = {"ALL YOUR BASE ARE", "BELONG TO US", NULL};
   gchar *aboutstring = _("A program to communicate with\nCreative Jukeboxes\nand MTP devices");
   gchar *translator_credits = _("translator_credits");
 
@@ -253,6 +253,8 @@ static void about_box(gpointer data)
     gtk_about_dialog_set_translator_credits(GTK_ABOUT_DIALOG(about), translator_credits);
   }
 #else
+  const gchar *thanks[] = {"ALL YOUR BASE ARE", "BELONG TO US", NULL};
+
   about = gnome_about_new(PACKAGE,
 			  VERSION,
 			  copystring,
@@ -271,7 +273,7 @@ static void about_box(gpointer data)
 
 void scan_jukebox(gpointer data)
 {
-  GtkWidget *label, *dialog, *button;
+  GtkWidget *label, *dialog;
   static scan_thread_arg_t scan_thread_args;
 
   if (!jukebox_selected()) {
@@ -353,8 +355,7 @@ static void set_owner_ok_button (GtkButton *button,
 /* A dialog to select the owner */
 static void set_jukeboxowner_dialog(gpointer data)
 {
-  GtkWidget *label, *button;
-  gchar *text;
+  GtkWidget *label;
   gchar *ownerstring;
 
 #if GTK_CHECK_VERSION(2,4,0)
@@ -462,20 +463,16 @@ int main(int argc,
   GtkWidget *menu_bar;
   GtkWidget *root_menu;
   GtkWidget *menu_item;
-  GtkWidget *accel_label;
   GtkWidget *music_panel;
   GtkWidget *data_panel;
 
-  GtkWidget *vbox, *hbox, *prefshbox;
+  GtkWidget *vbox, *prefshbox;
+  // GtkWidget *hbox;
   GtkWidget *notebook;
-  GtkWidget *frame;
   GtkWidget *label;
-  GtkWidget *checkbutton;
-  GdkColormap *cmap;
   GtkAccelGroup *accel_group;
   extern char *optarg;
   gint opt;
-  gint i;
   GError *icon_load_error = NULL;
 
   /* Binds for internationalization (i18n) */
@@ -504,15 +501,6 @@ int main(int argc,
     }
   }
   
-  cmap = gdk_colormap_get_system();
-  darkblue.red = 0u;
-  darkblue.green = 0u;
-  darkblue.blue = 0xffffu;
-  if (!gdk_colormap_alloc_color(cmap, &darkblue, FALSE, TRUE)) {
-    g_print(_("Could not allocate blue color!\n"));
-    gdk_color_black(cmap, &darkblue);
-  }
-
 #if GTK_CHECK_VERSION(2,6,0)
   main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (main_window), cProgramName);
@@ -699,5 +687,5 @@ int main(int argc,
   gtk_widget_show(main_window);
 
   gtk_main();
-  gtk_exit(0);
+  return 0;
 }
