@@ -26,9 +26,12 @@
 #include "filesystem.h"
 #include "filenaming.h"
 #include "util.h"
+#include "id3read.h"
 #if !GTK_CHECK_VERSION(2,4,0)
 #include <libgnomeui/libgnomeui.h>
 #endif
+#include <glib.h>
+#include <glib/gprintf.h>
 
 extern GtkWidget *main_window;
 
@@ -50,9 +53,9 @@ static gchar *jukebox_hardware = NULL;
 static u_int64_t jukebox_totalbytes = 0;
 static u_int64_t jukebox_freebytes = 0;
 static u_int64_t jukebox_usedbytes = 0;
-static guint jukebox_songs = 0;
-static guint jukebox_playlists = 0;
-static guint jukebox_datafiles = 0;
+static guint32 jukebox_songs = 0;
+static guint32 jukebox_playlists = 0;
+static guint32 jukebox_datafiles = 0;
 /* Variables used for playing tracks */
 static GList *playlist;
 static GList *playlistitr;
@@ -141,6 +144,21 @@ static const mtp_filetype_description_t mtp_filetype_descriptions[] = {
   { LIBMTP_FILETYPE_UNKNOWN, "N/A" }
 };
 
+/* Local static functions */
+
+/* Return disk usage */
+static void jukebox_getusage(guint64 *total, guint64 *free, guint64 *used, 
+			     guint32 *songs, guint32 *playlists, guint32 *datafiles)
+{
+  *total = jukebox_totalbytes;
+  *free = jukebox_freebytes;
+  *used = jukebox_usedbytes;
+  *songs = jukebox_songs;
+  *playlists = jukebox_playlists;
+  *datafiles = jukebox_datafiles;
+}
+
+
 static const mtp_filetype_description_t*
 get_mtp_filetype_description(LIBMTP_filetype_t type) {
   const mtp_filetype_description_t *current;
@@ -215,7 +233,6 @@ static gchar *jukebox_get_idstring(void)
   } else {
     if (pdedevice != NULL) {
       u_int8_t sdmiid[16];
-      gchar idstring[32];
       
       if (NJB_Get_SDMI_ID(pdedevice, (u_int8_t *) &sdmiid) == 0) {
 	return g_strdup_printf("%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X",
@@ -386,10 +403,10 @@ static void add_to_dialog(GtkWidget *dialog, GtkWidget *thing)
 /* This creates a device information dialog and returns it. */
 GtkWidget *jukebox_get_deviceinfo_dialog(void)
 {
-  GtkWidget *label, *button, *dialog, *hbox;
+  GtkWidget *label, *dialog, *hbox;
   gchar tmp[50];
   guint64 total, free, used;
-  guint songs, playlists, datafiles;
+  guint32 songs, playlists, datafiles;
 
   if (use_mtp) {
 #ifdef HAVE_LIBMTP
@@ -552,7 +569,7 @@ GtkWidget *jukebox_get_deviceinfo_dialog(void)
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   add_empty_hbox (hbox);
-  sprintf(tmp, "%Lu (%Lu MB)", 
+  sprintf(tmp, "%" PRIguint64 " (%" PRIguint64 " MB)", 
 	  total, (guint64) total/G_GINT64_CONSTANT(1048576));
   label = gtk_label_new(tmp);
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -565,7 +582,7 @@ GtkWidget *jukebox_get_deviceinfo_dialog(void)
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   add_empty_hbox (hbox);
-  sprintf(tmp, "%Lu (%Lu MB)", 
+  sprintf(tmp, "%" PRIguint64 " (%" PRIguint64 " MB)", 
 	  free, (guint64) free/G_GINT64_CONSTANT(1048576));
   label = gtk_label_new(tmp);
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -578,7 +595,7 @@ GtkWidget *jukebox_get_deviceinfo_dialog(void)
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   add_empty_hbox (hbox);
-  sprintf(tmp, "%Lu (%Lu MB)", 
+  sprintf(tmp, "%" PRIguint64 " (%" PRIguint64 " MB)", 
 	  used, (guint64) used/G_GINT64_CONSTANT(1048576));
   label = gtk_label_new(tmp);
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -591,7 +608,7 @@ GtkWidget *jukebox_get_deviceinfo_dialog(void)
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   add_empty_hbox (hbox);
-  sprintf(tmp, "%lu", songs);
+  sprintf(tmp, "%" PRIguint32, songs);
   label = gtk_label_new(tmp);
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show(label);
@@ -603,7 +620,7 @@ GtkWidget *jukebox_get_deviceinfo_dialog(void)
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   add_empty_hbox (hbox);
-  sprintf(tmp, "%lu", playlists);
+  sprintf(tmp, "%" PRIguint32, playlists);
   label = gtk_label_new(tmp);
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show(label);
@@ -615,7 +632,7 @@ GtkWidget *jukebox_get_deviceinfo_dialog(void)
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   add_empty_hbox (hbox);
-  sprintf(tmp, "%lu", datafiles);
+  sprintf(tmp, "%" PRIguint32, datafiles);
   label = gtk_label_new(tmp);
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show(label);
@@ -951,7 +968,7 @@ static void build_playlist_list()
 	// List of choices when transfering tracks
 	jukebox_playlists++;
 	jukebox_playlist = g_list_append(jukebox_playlist, g_strdup(pl->name));
-	jukebox_playlist = g_list_append(jukebox_playlist, GUINT_TO_POINTER(pl->playlist_id));
+	jukebox_playlist = g_list_append(jukebox_playlist, GUINT32_TO_GPOINTER((guint32) pl->playlist_id));
 
 	// Widget playlist tree
 	entry = (gnomadplaylist_entry_t *) g_malloc(sizeof(gnomadplaylist_entry_t));
@@ -959,13 +976,13 @@ static void build_playlist_list()
 	entry->plid = 0;
 	entry->tracklist = NULL;
 	entry->name = g_strdup(pl->name);
-	tmp = g_strdup_printf("%lu", pl->playlist_id);
+	tmp = g_strdup_printf("%" PRIguint32, (guint32) pl->playlist_id);
 	entry->plid = tmp;
 
 	// Then build the tree structure immediately
 	for (i = 0; i < pl->no_tracks; i++) {
 	  entry->tracklist = g_slist_append(entry->tracklist,
-					    GUINT_TO_POINTER(pl->tracks[i]));
+					    GUINT32_TO_GPOINTER((guint32) pl->tracks[i]));
 	}
 	playlistlist = g_slist_append(playlistlist, (gpointer) entry);
 	if (cancel_jukebox_operation)
@@ -980,59 +997,41 @@ static void build_playlist_list()
     njb_playlist_t *playlist;
     
     NJB_Reset_Get_Playlist(pdedevice);
-    while (playlist = NJB_Get_Playlist(pdedevice)) {
+    while ((playlist = NJB_Get_Playlist(pdedevice)) != NULL) {
+      gnomadplaylist_entry_t *entry;
+      gchar *tmp;
+      njb_playlist_track_t *track;
+
       jukebox_playlists++;
       jukebox_playlist = g_list_append(jukebox_playlist, g_strdup(playlist->name));
-      jukebox_playlist = g_list_append(jukebox_playlist, GUINT_TO_POINTER(playlist->plid));
-      // Dangerous?
-      NJB_Playlist_Destroy(playlist);
-    }
-  }
-}
-
-
-static void create_tree_structure()
-{
-  if (use_mtp) {
-    // Implemented as part of build_playlist_list()
-    return;
-  } else {
-    njb_playlist_t *playlist;
-
-    /* Set this too NULL to be certain */
-    playlistlist = NULL;
-    /* This is for the actual playlist tree scan */
-    NJB_Reset_Get_Playlist(pdedevice);
-    while (playlist = NJB_Get_Playlist(pdedevice)) {
-      njb_playlist_track_t *track;
-      gnomadplaylist_entry_t *entry;
-      gint i,j;
-      gchar *tmp;
+      jukebox_playlist = g_list_append(jukebox_playlist, GUINT32_TO_GPOINTER((guint32) playlist->plid));
 
+      // Widget playlist tree
       entry = (gnomadplaylist_entry_t *) g_malloc(sizeof(gnomadplaylist_entry_t));
       entry->name = NULL;
       entry->plid = 0;
       entry->tracklist = NULL;
       entry->name = g_strdup(playlist->name);
-      tmp = g_strdup_printf("%lu", playlist->plid);
+      tmp = g_strdup_printf("%" PRIguint32, (guint32) playlist->plid);
       entry->plid = tmp;
+      
+      // Then build the tree structure immediately
       NJB_Playlist_Reset_Gettrack(playlist);
-      while (track = NJB_Playlist_Gettrack(playlist)) {
+      while ((track = NJB_Playlist_Gettrack(playlist)) != NULL) {
 	entry->tracklist = g_slist_append(entry->tracklist,
-					  GUINT_TO_POINTER(track->trackid));
+					  GUINT32_TO_GPOINTER((guint32) track->trackid));
+	
       }
-      NJB_Playlist_Destroy(playlist);
       playlistlist = g_slist_append(playlistlist, (gpointer) entry);
       if (cancel_jukebox_operation)
 	break;
-    }
-    if ( NJB_Error_Pending(pdedevice) ) {
-      NJB_Error_Dump(pdedevice,stderr);
+
+      // Dangerous?
+      NJB_Playlist_Destroy(playlist);
     }
   }
 }
 
-
 static void build_tree_widget(GtkTreeStore *pltreestore)
 {
   GSList *tmplist;
@@ -1043,7 +1042,6 @@ static void build_tree_widget(GtkTreeStore *pltreestore)
   while (tmplist != NULL) {
     gnomadplaylist_entry_t *entry;
     GSList *tmplist2;
-    gint i;
     GtkTreeIter treeiter;
     
     entry = (gnomadplaylist_entry_t *) tmplist->data;
@@ -1060,14 +1058,15 @@ static void build_tree_widget(GtkTreeStore *pltreestore)
       metadata_t *meta;
       GtkTreeIter treeiter2;
 
-      // g_print("Track: %lu\n", GPOINTER_TO_UINT(tmplist2->data));
+      // g_print("Track: %" PRIguint32 "\n", GPOINTER_TO_GUINT32(tmplist2->data));
       meta = (metadata_t *) g_hash_table_lookup(songhash, tmplist2->data);
       /*
        * This might have caused lots of trouble to people with bad tracks 
        * in their playlists... Fixed 2004-03-09 Linus Walleij
        */
       if (meta != NULL) {
-	// g_print("Adding song with ID %lu to playlist %lu\n", GPOINTER_TO_UINT(tmplist2->data), entry->plid);
+	// g_print("Adding song with ID %" PRIguint32 " to playlist %" PRIguint32 "\n", 
+	// GPOINTER_TO_GUINT32(tmplist2->data), entry->plid);
 	// dump_metadata_t(meta);
 	gtk_tree_store_append (GTK_TREE_STORE(pltreestore), &treeiter2, &treeiter);
 	gtk_tree_store_set(GTK_TREE_STORE(pltreestore), &treeiter2,
@@ -1078,7 +1077,7 @@ static void build_tree_widget(GtkTreeStore *pltreestore)
 			   PLIST_SONGID_COLUMN, meta->path,
 			   -1);
       } else {
-	g_print("Bad track detected in playlist, track ID: %lu\n", GPOINTER_TO_UINT(tmplist2->data));
+	g_print("Bad track detected in playlist, track ID: %" PRIguint32 "\n", GPOINTER_TO_GUINT32(tmplist2->data));
       }
       tmplist2 = tmplist2->next;
     }
@@ -1111,9 +1110,6 @@ void build_playlist_tree(GtkTreeStore *pltreestore)
   jukebox_locked = TRUE;
   /* First build the structure for dialog boxes */
   build_playlist_list();
-  /* Next get the playlists and their respective tracks
-   * from the jukebox */
-  create_tree_structure();
   /* Now we are finished with the jukebox communication and we have
    * all playlists in memory, so let's enter the GTK thread and
    * redraw the tree. */
@@ -1209,8 +1205,6 @@ static GSList *filter_datafile_list(gchar *filter)
   metadata_t *meta;
   gchar **tmp;
   int veclen;
-  gchar *foldername;
-  gchar *basename;
   
   if (filter == NULL) {
     return NULL;
@@ -1367,13 +1361,13 @@ static gboolean call_rebuild_datafile_list(gpointer data)
 gpointer scan_thread(gpointer thread_args)
 {
   gboolean last_item = FALSE;
-  njb_songid_t *songtag;
-  njb_datafile_t *datatag;
+  njb_songid_t *songtag = NULL;  /* initialize to shut up GCC */
+  njb_datafile_t *datatag = NULL;  /* initialize to shut up GCC */
 #ifdef HAVE_LIBMTP
   LIBMTP_track_t *mtptracks;
-  LIBMTP_track_t *mtptrack;
+  LIBMTP_track_t *mtptrack = NULL;  /* initialize to shut up GCC */
   LIBMTP_file_t *mtpfiles;
-  LIBMTP_file_t *mtpfile;
+  LIBMTP_file_t *mtpfile = NULL;  /* initialize to shut up GCC */
 #endif
   draw_label_args_t *da;
   scan_thread_arg_t *args = (scan_thread_arg_t *) thread_args;
@@ -1445,14 +1439,13 @@ gpointer scan_thread(gpointer thread_args)
    */
   
   while (!last_item) {
-    gint i;
     metadata_t *meta;
 
     jukebox_songs++;
     /* Number of songs scanned during scan. */
     da = (draw_label_args_t *) g_malloc(sizeof(draw_label_args_t));
     da->label = args->label;
-    da->text = g_strdup_printf(_("%u songs scanned"), jukebox_songs);
+    da->text = g_strdup_printf(_("%" PRIguint32 " songs scanned"), jukebox_songs);
     g_idle_add(draw_label, da);
     
     // Create a structure to hold the data in the columns
@@ -1468,7 +1461,7 @@ gpointer scan_thread(gpointer thread_args)
       filetype_d = get_mtp_filetype_description(mtptrack->filetype);
 
       // Add to metadata holder
-      meta->path = g_strdup_printf("%lu", mtptrack->item_id);
+      meta->path = g_strdup_printf("%" PRIguint32, (guint32) mtptrack->item_id);
       meta->artist = g_strdup(mtptrack->artist);
       meta->title = g_strdup(mtptrack->title);
       meta->genre = g_strdup(mtptrack->genre);
@@ -1483,7 +1476,7 @@ gpointer scan_thread(gpointer thread_args)
 	// Terminate after the year
 	tmpyear[4] = '\0';
 	// Convert to a figure.
-	meta->year = string_to_guint(tmpyear);
+	meta->year = string_to_guint32(tmpyear);
       }
       if (tmpyear != NULL) {
 	g_free(tmpyear);
@@ -1506,10 +1499,10 @@ gpointer scan_thread(gpointer thread_args)
       njb_songid_frame_t *frame;
 
       NJB_Songid_Reset_Getframe(songtag);
-      meta->path = g_strdup_printf("%lu", songtag->trid);
+      meta->path = g_strdup_printf("%" PRIguint32, (guint32) songtag->trid);
       
       /* Loop through the song tags */
-      while(frame = NJB_Songid_Getframe(songtag)){
+      while((frame = NJB_Songid_Getframe(songtag)) != NULL){
 	// FIXME: add progress bar for scanning?
 	
 	if (!strcmp(frame->label, FR_ARTIST)) {
@@ -1564,7 +1557,7 @@ gpointer scan_thread(gpointer thread_args)
       dump_metadata_t(meta);
     }
     g_hash_table_insert(songhash,
-			GUINT_TO_POINTER(string_to_guint(meta->path)),
+			GUINT32_TO_GPOINTER(string_to_guint32(meta->path)),
 			(gpointer) meta);
     if (cancel_jukebox_operation)
       break;
@@ -1604,14 +1597,12 @@ gpointer scan_thread(gpointer thread_args)
   while (!last_item) {
     metadata_t *meta;
     u_int64_t filesize;
-    gint i;
-    gchar *scanstring;
     
     jukebox_datafiles++;
 
     da = (draw_label_args_t *) g_malloc(sizeof(draw_label_args_t));
     da->label = args->label;
-    da->text = g_strdup_printf(_("%u data files scanned"), jukebox_datafiles);
+    da->text = g_strdup_printf(_("%" PRIguint32 " data files scanned"), jukebox_datafiles);
     g_idle_add(draw_label, da);
 
     // Create a structure to hold the data in the columns
@@ -1621,7 +1612,7 @@ gpointer scan_thread(gpointer thread_args)
 #ifdef HAVE_LIBMTP
       LIBMTP_file_t *tmp;
       // Add to metadata holder
-      meta->path = g_strdup_printf("%lu", mtpfile->item_id);
+      meta->path = g_strdup_printf("%" PRIguint32, (guint32) mtpfile->item_id);
       meta->size = (guint32) mtpfile->filesize;
       meta->filename = g_strdup(mtpfile->filename);
       // These two are not supported yet.
@@ -1658,7 +1649,7 @@ gpointer scan_thread(gpointer thread_args)
 	meta->filename = g_strdup(datatag->filename);
       }
       /* File ID */
-      meta->path = g_strdup_printf("%lu", datatag->dfid);
+      meta->path = g_strdup_printf("%" PRIguint32, (guint32) datatag->dfid);
       // destroy_metadata_t(meta);
       NJB_Datafile_Destroy (datatag);
       datatag = NJB_Get_Datafile_Tag(pdedevice);
@@ -1689,9 +1680,10 @@ gpointer scan_thread(gpointer thread_args)
   g_idle_add((GSourceFunc) gtk_widget_destroy, args->dialog);
   
   jukebox_locked = FALSE;
+  return NULL;
 }
 
-static set_progress_fraction(guint64 const sent, guint64 const total)
+static void set_progress_fraction(guint64 const sent, guint64 const total)
 {
   draw_progress_args_t *dp;
   
@@ -1726,6 +1718,7 @@ static int mtp_progress (uint64_t const sent, uint64_t const total,
 {
   set_progress_fraction(sent, total);
   // TODO: cancellation
+  return 0;
 }
 #endif
 
@@ -1734,11 +1727,9 @@ static int mtp_progress (uint64_t const sent, uint64_t const total,
  * operations to the main loop.
  */
 
-static gboolean call_fill_in_dir(gpointer data)
+static gboolean call_fill_in_dir(gpointer what)
 {
-  guint what = (guint) data;
-
-  fill_in_dir(what, get_current_dir());
+  fill_in_dir((listtype_t)GPOINTER_TO_INT(what), get_current_dir());
   return FALSE;
 }
 
@@ -1796,7 +1787,7 @@ gpointer jb2hd_thread(gpointer thread_args)
       }
 
       create_dirs(tmpfname);
-      id = string_to_guint(jbmeta->path);
+      id = string_to_guint32(jbmeta->path);
 
       // Draw next file
       da = (draw_label_args_t *) g_malloc(sizeof(draw_label_args_t));
@@ -1837,7 +1828,7 @@ gpointer jb2hd_thread(gpointer thread_args)
       if (get_prefs_useid3()) {
 	if (meta->codec != NULL &&
 	    !strcmp(meta->codec, "MP3")) {
-	  set_tag_for_mp3file (meta, tmpfname, get_prefs_id3override());
+	  set_tag_for_mp3file (meta, get_prefs_id3override());
 	}
       }
       
@@ -1857,10 +1848,11 @@ gpointer jb2hd_thread(gpointer thread_args)
 
   jukebox_locked = FALSE;
   g_idle_add((GSourceFunc) gtk_widget_destroy, args->dialog);
-  g_idle_add(call_fill_in_dir, (gpointer) HD_LIST);
+  g_idle_add(call_fill_in_dir, GINT_TO_POINTER((gint)HD_LIST));
   /* Free the memory used by the list */
   destroy_metalist(args->metalist);
   g_free(args);
+  return NULL;
 }
 
 
@@ -1884,7 +1876,7 @@ gpointer jb2hd_data_thread(gpointer thread_args)
       metadata_add_args_t *metaddarg;
       
       jbmeta = (metadata_t *) metalist->data;
-      id = string_to_guint(jbmeta->path);
+      id = string_to_guint32(jbmeta->path);
 
       // Draw next file
       da = (draw_label_args_t *) g_malloc(sizeof(draw_label_args_t));
@@ -1937,8 +1929,9 @@ gpointer jb2hd_data_thread(gpointer thread_args)
   destroy_metalist(args->metalist);
   jukebox_locked = FALSE;
   g_idle_add((GSourceFunc) gtk_widget_destroy, args->dialog);
-  g_idle_add(call_fill_in_dir, (gpointer) HDDATA_LIST);
+  g_idle_add(call_fill_in_dir, GINT_TO_POINTER((gint)HDDATA_LIST));
   g_free(args);
+  return NULL;
 }
 
 
@@ -1951,13 +1944,18 @@ gpointer hd2jb_thread(gpointer thread_args)
   hd2jb_thread_arg_t *args = (hd2jb_thread_arg_t *) thread_args;
   GList *templist = args->metalist;
   GList *new_metalist = NULL;
-  gchar *tmpdirname;
+  gchar *tmpdirname = NULL;
+#ifndef G_OS_WIN32
+  gchar tmpdirtmpl[] = "/tmp/gnomad-XXXXXX";
+#else
+  // FIXME: I'm not quite sure this always works on Windows.
+  gchar tmpdirtmpl[] = "C:\\gnomad-XXXXXX";
+#endif
 
   // Create a temporary directory for tag-stripped files.
   if (get_prefs_id3remove()) {
-    tmpdirname = tmpnam(NULL);
-    // Create it.
-    if (!create_directory(tmpdirname)) {
+	tmpdirname = mkdtemp(tmpdirtmpl);
+    if (tmpdirname == NULL) {
       goto hd2jb_cleanup;
     }
   }
@@ -1970,7 +1968,8 @@ gpointer hd2jb_thread(gpointer thread_args)
       gint protectint;
       gchar *tmpfname = NULL;
       gchar *tmpfname8 = NULL;
-      u_int32_t id, length;
+      guint32 id;
+      guint length;
       gboolean clone_and_strip = FALSE;
       draw_label_args_t *da;
       draw_progress_args_t *dp;
@@ -1980,7 +1979,7 @@ gpointer hd2jb_thread(gpointer thread_args)
       // g_print("Storing %s on jukebox...\n", hdmeta->filename);
 
       // If we want to remove ID3 tags then we fix that here
-      if (get_prefs_id3remove() && !strcmp(hdmeta->codec, "MP3")) {
+      if (tmpdirname != NULL && !strcmp(hdmeta->codec, "MP3")) {
 	clone_and_strip = TRUE;
 	tmpfname8 = g_build_filename(tmpdirname, hdmeta->filename, NULL);
 	tmpfname = filename_fromutf8(tmpfname8);
@@ -2037,7 +2036,7 @@ gpointer hd2jb_thread(gpointer thread_args)
 	  goto hd2jb_cleanup;
 	}
 	// Fetch new track ID.
-	id = trackmeta->item_id;
+	id = (guint32) trackmeta->item_id;
 	LIBMTP_destroy_track_t(trackmeta);
 #endif
       } else {
@@ -2062,7 +2061,7 @@ gpointer hd2jb_thread(gpointer thread_args)
 	NJB_Songid_Addframe(songid, frame);
 	frame = NJB_Songid_Frame_New_Tracknum(hdmeta->trackno);
 	NJB_Songid_Addframe(songid, frame);
-	frame = NJB_Songid_Frame_New_Length(length);
+	frame = NJB_Songid_Frame_New_Length((u_int32_t) length);
 	NJB_Songid_Addframe(songid, frame);
 	frame = NJB_Songid_Frame_New_Filename(hdmeta->filename);
 	NJB_Songid_Addframe(songid, frame);
@@ -2074,7 +2073,7 @@ gpointer hd2jb_thread(gpointer thread_args)
 	// g_print("Transferring track.\n");
 	if (NJB_Send_Track (pdedevice, tmpfname, songid,
 			    pde_progress, NULL, 
-			    &id) == -1) {
+			    (u_int32_t *) &id) == -1) {
 	  NJB_Error_Dump(pdedevice, stderr);
 	  goto hd2jb_cleanup;
 	}
@@ -2087,7 +2086,7 @@ gpointer hd2jb_thread(gpointer thread_args)
       /* Add correct trackid in col 7, add the row */
       jbmeta = clone_metadata_t(hdmeta);
       g_free(jbmeta->path);
-      jbmeta->path = g_strdup_printf("%lu", id);
+      jbmeta->path = g_strdup_printf("%" PRIguint32, id);
 
       /* Send to main loop for drawing */
       metaddarg = (metadata_add_args_t *) g_malloc(sizeof(metadata_add_args_t));
@@ -2096,7 +2095,7 @@ gpointer hd2jb_thread(gpointer thread_args)
       g_idle_add(call_add_metadata_to_model,metaddarg);
 
       g_hash_table_insert(songhash,
-			  GUINT_TO_POINTER(id),
+			  GUINT32_TO_GPOINTER(id),
 			  (gpointer) clone_metadata_t(jbmeta));
       new_metalist = g_list_append (new_metalist, jbmeta);
       if (clone_and_strip) {
@@ -2124,7 +2123,7 @@ gpointer hd2jb_thread(gpointer thread_args)
  hd2jb_cleanup:
 
   // Remove temporary directory for tag-stripped files.
-  if (get_prefs_id3remove()) {
+  if (tmpdirname != NULL) {
     rmdir(tmpdirname);
   }
   
@@ -2136,6 +2135,7 @@ gpointer hd2jb_thread(gpointer thread_args)
   g_list_free(args->playlists);
   destroy_metalist(args->metalist);
   g_free(args);
+  return NULL;
 }
 
 
@@ -2154,7 +2154,7 @@ gpointer hd2jb_data_thread(gpointer thread_args)
       gchar *tmpfname;
       gchar *folder;
       gchar rootdir[] = "\\";
-      u_int32_t id;
+      guint32 id;
       metadata_t *hdmeta;
       metadata_t *jbmeta;
       draw_label_args_t *da;
@@ -2200,7 +2200,7 @@ gpointer hd2jb_data_thread(gpointer thread_args)
 	LIBMTP_destroy_file_t(filemeta);
 #endif
       } else {
-	if (NJB_Send_File (pdedevice, tmpfname, hdmeta->filename, folder, pde_progress, NULL, &id) == -1) {
+	if (NJB_Send_File (pdedevice, tmpfname, hdmeta->filename, folder, pde_progress, NULL, (u_int32_t *) &id) == -1) {
 	  g_free(tmpfname);
 	  NJB_Error_Dump(pdedevice, stderr);
 	  goto hd2jb_data_cleanup;
@@ -2215,7 +2215,7 @@ gpointer hd2jb_data_thread(gpointer thread_args)
        * be freed correctly */
       jbmeta = clone_metadata_t(hdmeta);
       g_free(jbmeta->path);
-      jbmeta->path = g_strdup_printf("%lu", id);
+      jbmeta->path = g_strdup_printf("%" PRIguint32, id);
       if (jbmeta->folder != NULL) {
 	g_free(jbmeta->folder);
       }
@@ -2239,13 +2239,13 @@ gpointer hd2jb_data_thread(gpointer thread_args)
   jukebox_locked = FALSE;
   destroy_metalist(args->metalist);
   g_free(args);
+  return NULL;
 }
 
 
 #ifdef HAVE_LIBMTP
 static gboolean delete_one_track_from_playlist(LIBMTP_playlist_t *pl, uint32_t trackid)
 {
-  LIBMTP_playlist_t *tmp;
   guint i;
   guint instances = 0;
 
@@ -2301,7 +2301,7 @@ static void remove_tracks_from_playlists(GList *metalist,
     u_int32_t id;  
     
     meta = (metadata_t *) tmplist->data;
-    id = string_to_guint(meta->path);
+    id = string_to_guint32(meta->path);
 
     if (use_mtp) {
 #ifdef HAVE_LIBMTP
@@ -2331,7 +2331,7 @@ static void remove_tracks_from_playlists(GList *metalist,
 
       NJB_Reset_Get_Playlist(pdedevice);
 
-      while (playlist = NJB_Get_Playlist(pdedevice)) {
+      while ((playlist = NJB_Get_Playlist(pdedevice)) != NULL) {
 	NJB_Playlist_Deltrack_TrackID(playlist, id);
 	/* If the playlist changed, update it */
 	if (playlist->_state == NJB_PL_CHTRACKS) {
@@ -2358,23 +2358,22 @@ void jukebox_delete_files(GList *metalist)
     return;
   jukebox_locked = TRUE;
   while (tmplist) {
-    u_int32_t id;
-    char *dummy;
+    guint32 id;
     metadata_t *meta;
     
     meta = (metadata_t *) tmplist->data;
-    id = string_to_guint(meta->path);
-    /* g_print("Deleting: %u from jukebox library\n", id); */
+    id = string_to_guint32(meta->path);
+    /* g_print("Deleting: %" PRIguint32 " from jukebox library\n", id); */
     if (id) {
       if (use_mtp) {
 #ifdef HAVE_LIBMTP
-	if (LIBMTP_Delete_Object(mtpdevice, id) != 0) {
+	if (LIBMTP_Delete_Object(mtpdevice, (uint32_t) id) != 0) {
 	  // Error message
 	  g_print("Unable to delete files.\n");
 	}
 #endif
       } else {
-	if ( NJB_Delete_Datafile(pdedevice, id) == -1 ) {
+	if ( NJB_Delete_Datafile(pdedevice, (u_int32_t) id) == -1 ) {
 	  NJB_Error_Dump(pdedevice, stderr);
 	}
       }
@@ -2406,7 +2405,7 @@ void jukebox_delete_tracks(GList *metalist,
     u_int32_t id;
     
     meta = (metadata_t *) tmplist->data;
-    id = string_to_guint(meta->path);
+    id = string_to_guint32(meta->path);
     /* g_print("Deleting: %lu from jukebox library\n", id); */
     if (id) {
       metadata_t *tmpmeta;
@@ -2453,7 +2452,7 @@ void jukebox_set_metadata (metadata_t *meta)
   u_int32_t id, length;
   metadata_t *tmpmeta;
 
-  id = string_to_guint(meta->path);
+  id = string_to_guint32(meta->path);
   length = mmss_to_seconds(meta->length);
   if (id == 0) {
     create_error_dialog(_("Track ID was zero! Illegal value!"));
@@ -2573,10 +2572,10 @@ void jukebox_end_metadata_set(void)
 }
 
 /* Creates a new playlist and returns its playlist ID UNTHREADED */
-guint jukebox_create_playlist(gchar *plname, GtkTreeStore *pltreestore)
+guint32 jukebox_create_playlist(gchar *plname, GtkTreeStore *pltreestore)
 {
   njb_playlist_t *playlist;
-  guint plid = 0;
+  guint32 plid = 0;
 
   /* g_print("Called create playlist\n"); */
   if (use_mtp) {
@@ -2609,7 +2608,7 @@ guint jukebox_create_playlist(gchar *plname, GtkTreeStore *pltreestore)
       NJB_Error_Dump(pdedevice, stderr);
     }
     jukebox_playlists++;
-    plid = playlist->plid;
+    plid = (guint32) playlist->plid;
     NJB_Playlist_Destroy(playlist);
   }
   build_playlist_tree(pltreestore);
@@ -2619,17 +2618,17 @@ guint jukebox_create_playlist(gchar *plname, GtkTreeStore *pltreestore)
 }
 
 /* Delete a playlist with playlist ID plid UNTHREADED */
-void jukebox_delete_playlist(guint plid)
+void jukebox_delete_playlist(guint32 plid)
 {
   jukebox_locked = TRUE;
   if (use_mtp) {
 #ifdef HAVE_LIBMTP
-    if (LIBMTP_Delete_Object(mtpdevice, plid) != 0) {
+    if (LIBMTP_Delete_Object(mtpdevice, (uint32_t) plid) != 0) {
       create_error_dialog(_("Could not delete playlist"));
     }
 #endif
   } else {
-    if (NJB_Delete_Playlist(pdedevice, plid) == -1) {
+    if (NJB_Delete_Playlist(pdedevice, (u_int32_t) plid) == -1) {
       create_error_dialog(_("Could not delete playlist"));
       NJB_Error_Dump(pdedevice, stderr);
     }
@@ -2640,14 +2639,14 @@ void jukebox_delete_playlist(guint plid)
 }
 
 /* Rename the playlist with ID plid */
-void jukebox_rename_playlist(guint plid, gchar *name, GtkTreeStore *pltreestore)
+void jukebox_rename_playlist(guint32 plid, gchar *name, GtkTreeStore *pltreestore)
 {
   if (use_mtp) {
 #ifdef HAVE_LIBMTP
     // Get metadata for one single playlist, update and write back.
     LIBMTP_playlist_t *pl;
 
-    pl = LIBMTP_Get_Playlist(mtpdevice, plid);
+    pl = LIBMTP_Get_Playlist(mtpdevice, (uint32_t) plid);
     if (pl->name != NULL) {
       g_free(pl->name);
     }
@@ -2663,9 +2662,9 @@ void jukebox_rename_playlist(guint plid, gchar *name, GtkTreeStore *pltreestore)
   
     jukebox_locked = TRUE;
     NJB_Reset_Get_Playlist(pdedevice);
-    while (playlist = NJB_Get_Playlist(pdedevice)) {
-      /* g_print("Playlist %u == Playlist %u ... ",playlist->plid, plid); */
-      if (playlist->plid == plid) {
+    while ((playlist = NJB_Get_Playlist(pdedevice)) != NULL) {
+      /* g_print("Playlist %" PRIguint32 " == Playlist %" PRIguint32 " ... ",playlist->plid, plid); */
+      if (playlist->plid == (u_int32_t) plid) {
 	/* g_print("Yes.\n"); */
 	found = TRUE;
 	break;
@@ -2691,7 +2690,7 @@ void jukebox_rename_playlist(guint plid, gchar *name, GtkTreeStore *pltreestore)
   }
 }
 
-static void add_tracks_to_single_playlist(guint playlistid, GList *metalist)
+static void add_tracks_to_single_playlist(guint32 playlistid, GList *metalist)
 {
   // Sanity check
   if (!metalist)
@@ -2706,9 +2705,9 @@ static void add_tracks_to_single_playlist(guint playlistid, GList *metalist)
     uint32_t *copy;
 
     if (gnomad_debug != 0) {
-      g_print("Getting playlist %d\n", playlistid);
+      g_print("Getting playlist %" PRIguint32 "\n", playlistid);
     }
-    pl = LIBMTP_Get_Playlist(mtpdevice, playlistid);
+    pl = LIBMTP_Get_Playlist(mtpdevice, (uint32_t) playlistid);
     if (pl == NULL) {
       return;
     }
@@ -2740,14 +2739,14 @@ static void add_tracks_to_single_playlist(guint playlistid, GList *metalist)
     tmplist = metalist;
     while(tmplist) {
       metadata_t *meta;
-      uint32_t id;
+      guint32 id;
       
       meta = (metadata_t *) tmplist->data;
-      id = string_to_guint(meta->path);
+      id = string_to_guint32(meta->path);
       if (gnomad_debug != 0) {
-	g_print("Adding track %lu to playlist %lu\n", id, playlistid);
+	g_print("Adding track %" PRIguint32 " to playlist %" PRIguint32 "\n", id, playlistid);
       }
-      pl->tracks[i] = id;
+      pl->tracks[i] = (uint32_t) id;
       tmplist = g_list_next(tmplist);
       i++;
     }
@@ -2762,8 +2761,8 @@ static void add_tracks_to_single_playlist(guint playlistid, GList *metalist)
     gboolean found = FALSE;
     
     NJB_Reset_Get_Playlist(pdedevice);
-    while (playlist = NJB_Get_Playlist(pdedevice)) {
-      /* g_print("Is it %lu?\n", playlist->plid); */
+    while ((playlist = NJB_Get_Playlist(pdedevice)) != NULL) {
+      /* g_print("Is it %lu?\n", playlist->plid */
       if (playlist->plid == playlistid) {
 	/* g_print("YES!\n"); */
 	found = TRUE;
@@ -2780,7 +2779,7 @@ static void add_tracks_to_single_playlist(guint playlistid, GList *metalist)
 	u_int32_t id;
 	
 	meta = (metadata_t *) tmplist->data;
-	id = string_to_guint(meta->path);
+	id = string_to_guint32(meta->path);
 	/* g_print("Adding track %lu to playlist %lu\n", id, playlistid); */
 	pl_track = NJB_Playlist_Track_New(id);
 	NJB_Playlist_Addtrack(playlist, pl_track, NJB_PL_END);
@@ -2806,7 +2805,7 @@ void add_tracks_to_playlists(GList *playlists, GList *metalist)
   jukebox_locked = TRUE;
   cancel_jukebox_operation = FALSE;
   while (templist != NULL) {
-    guint plid = GPOINTER_TO_UINT(templist->data);
+    guint32 plid = GPOINTER_TO_GUINT32(templist->data);
     add_tracks_to_single_playlist(plid, metalist);
     templist = g_list_next(templist);
   }
@@ -2831,7 +2830,7 @@ guint jukebox_randomize_playlist(guint plist, GtkTreeStore *pltreestore)
     jukebox_locked = TRUE;
     // g_print("randomizing playlist %lu\n", plist);
     NJB_Reset_Get_Playlist(pdedevice);
-    while (playlist = NJB_Get_Playlist(pdedevice)) {
+    while ((playlist = NJB_Get_Playlist(pdedevice)) != NULL) {
       // g_print("Is it %lu?\n", playlist->plid);
       if (playlist->plid == plist) {
 	// g_print("YES!");
@@ -2908,7 +2907,7 @@ guint jukebox_randomize_playlist(guint plist, GtkTreeStore *pltreestore)
 }
 
 /* Delete file from playlist UNTHREADED */
-guint jukebox_delete_track_from_playlist(guint trackid, guint plist, GtkTreeStore *pltreestore)
+guint jukebox_delete_track_from_playlist(guint32 trackid, guint32 plist, GtkTreeStore *pltreestore)
 {
   guint new_plid = plist;
 
@@ -2916,7 +2915,7 @@ guint jukebox_delete_track_from_playlist(guint trackid, guint plist, GtkTreeStor
 
 
     jukebox_locked = TRUE;
-    g_print("Removing track: %lu from playlist %lu\n", trackid, plist);
+    g_print("Removing track: %" PRIguint32 " from playlist %" PRIguint32 "\n", trackid, plist);
 
     if (use_mtp) {
 #ifdef HAVE_LIBMTP
@@ -2927,7 +2926,8 @@ guint jukebox_delete_track_from_playlist(guint trackid, guint plist, GtkTreeStor
 	g_print("Failed to locate playlist for track removal.\n");
       } else {
 	if (!delete_one_track_from_playlist(pl, trackid)) {
-	  g_print("Failed to remove track %d from playlist %d\n", trackid, pl->playlist_id);
+	  g_print("Failed to remove track %" PRIguint32 " from playlist %" PRIguint32 "\n", 
+		  trackid, (guint32) pl->playlist_id);
 	}
 	LIBMTP_destroy_playlist_t(pl);
       }
@@ -2936,7 +2936,7 @@ guint jukebox_delete_track_from_playlist(guint trackid, guint plist, GtkTreeStor
       gboolean found = FALSE;
       njb_playlist_t *playlist;
       NJB_Reset_Get_Playlist(pdedevice);
-      while (playlist = NJB_Get_Playlist(pdedevice)) {
+      while ((playlist = NJB_Get_Playlist(pdedevice)) != NULL) {
 	// g_print("Is it in %lu? ...", playlist->plid);
 	if (playlist->plid == plist) {
 	  // g_print("YES!\n");
@@ -2951,7 +2951,7 @@ guint jukebox_delete_track_from_playlist(guint trackid, guint plist, GtkTreeStor
 	njb_playlist_track_t *track;
 	
 	// g_print("Found playlist %lu\n", playlist->plid);
-	while (track = NJB_Playlist_Gettrack(playlist)) {
+	while ((track = NJB_Playlist_Gettrack(playlist)) != NULL) {
 	  if (trackid == track->trackid) {
 	    /* When the track is located in a playlist, remove it */
 	    // g_print("Removing track: %lu from playlist %lu\n", track->trackid, playlist->plid);
@@ -3017,20 +3017,6 @@ void jukebox_set_ownerstring(gchar *owner)
   jukebox_locked = FALSE;
 }
 
-/* Return disk usage */
-#ifdef G_HAVE_GINT64
-void jukebox_getusage(guint64 *total, guint64 *free, guint64 *used, 
-		      guint *songs, guint *playlists, guint *datafiles)
-{
-  *total = jukebox_totalbytes;
-  *free = jukebox_freebytes;
-  *used = jukebox_usedbytes;
-  *songs = jukebox_songs;
-  *playlists = jukebox_playlists;
-  *datafiles = jukebox_datafiles;
-}
-#endif
-
 /* Returns the hh:mm:ss representation from seconds */
 static void hhmmss (u_int16_t seconds, u_int16_t *hh, u_int16_t *mm, u_int16_t *ss)
 {
@@ -3105,7 +3091,7 @@ GList *jukebox_get_playlist_for_play(guint plid)
 
   jukebox_locked = TRUE;
   NJB_Reset_Get_Playlist(pdedevice);
-  while (playlist = NJB_Get_Playlist(pdedevice)) {
+  while ((playlist = NJB_Get_Playlist(pdedevice)) != NULL) {
     if (playlist->plid == plid) {
       found = TRUE;
       break;
@@ -3118,9 +3104,8 @@ GList *jukebox_get_playlist_for_play(guint plid)
     njb_playlist_track_t *track;
     metadata_t *meta;
     metadata_t *newmeta;
-    gchar *tmp;
 
-    while (track = NJB_Playlist_Gettrack(playlist)) {
+    while ((track = NJB_Playlist_Gettrack(playlist)) != NULL) {
       meta = (metadata_t *) g_hash_table_lookup(songhash,
 						GUINT_TO_POINTER(track->trackid));
       // Sometimes it's non-existant
@@ -3152,7 +3137,7 @@ static void send_playlist(GList *list)
     u_int32_t id;
 
     meta = (metadata_t *) tmplist->data;
-    id = string_to_guint(meta->path);
+    id = string_to_guint32(meta->path);
     if (id) {
       if (first) {
 	/* g_print("Playing: %lu\n", id); */
@@ -3257,8 +3242,6 @@ void jukebox_next(gboolean already_playing)
 
 static void jukebox_current(void)
 {
-  GList *tmplist;
-
   /* g_print("Called jukebox_current...\n"); */
   if (playlistitr != NULL) {
     metadata_t *meta;
@@ -3294,7 +3277,7 @@ gpointer play_thread(gpointer thread_args)
 
   /* Just mail out on MTP devices */
   if (use_mtp) {
-    return;
+    return NULL;
   }
   /* This mutex is to avoid collisions with EAX changes */
   if (!created_play_mutex) {
@@ -3311,7 +3294,7 @@ gpointer play_thread(gpointer thread_args)
   passed_first_zero = FALSE;
   if (!playlist) {
     g_mutex_unlock(play_thread_mutex);
-    return;
+    return NULL;
   }
   /* The iterator is used for walking the playlist */
   playlistitr = playlist;
@@ -3396,6 +3379,7 @@ gpointer play_thread(gpointer thread_args)
   NJB_Stop_Play(pdedevice);
   g_mutex_unlock(play_thread_mutex);
   jukebox_locked = FALSE;
+  return NULL;
 }
 
 /* This routine synchronize the time on the
@@ -3414,12 +3398,13 @@ void jukebox_synchronize_time(void)
   } else {
     njb_time_t *jukeboxtime;
     struct tm *tm;
+    const time_t tt_currenttime = currenttime;
   
     // Get the time from the jukebox, then modify it.
     jukeboxtime = NJB_Get_Time(pdedevice);
 
     // Uses UNIX library calls, might need to be portablized
-    tm = localtime((time_t *) &currenttime);
+    tm = localtime(&tt_currenttime);
     /*
       g_print("Setting: %d-%d-%d (wkd: %d) %d:%d:%d\n", 1900+tm->tm_year,
       1+tm->tm_mon, tm->tm_mday, tm->tm_wday-1,
@@ -3444,7 +3429,7 @@ void jukebox_synchronize_time(void)
 void jukebox_create_folder(gchar *foldername)
 {
   gchar rootdir[] = "\\";
-  u_int32_t id;
+  guint32 id;
   metadata_t *jbmeta;
   gchar *folder;
   
@@ -3465,14 +3450,14 @@ void jukebox_create_folder(gchar *foldername)
     return;
   }
 
-  if (NJB_Create_Folder (pdedevice, jbmeta->folder, &id) == -1) {
+  if (NJB_Create_Folder (pdedevice, jbmeta->folder, (u_int32_t *) &id) == -1) {
     // Error back off
     destroy_metadata_t(jbmeta);
     NJB_Error_Dump(pdedevice, stderr);
     create_error_dialog(_("The folder could not be created.\nThe most typical reason is that you are using a Nomad Jukebox 1\nwhich is too old to support folders."));
     return;
   }
-  jbmeta->path = g_strdup_printf("%lu", id);
+  jbmeta->path = g_strdup_printf("%" PRIguint32, id);
   /* Keep this in the global metadata file list! */
   datafilelist = g_slist_append(datafilelist, (gpointer) jbmeta);
   // Redraw
