@@ -107,18 +107,16 @@ void jukebox_delete_files(GList *metalist);
 gboolean jukebox_begin_metadata_set(void);
 void jukebox_set_metadata (metadata_t *meta);
 void jukebox_end_metadata_set(void);
-guint jukebox_create_playlist(gchar *plname, GtkTreeStore *pltreestore);
-void jukebox_delete_playlist(guint plid);
-void jukebox_rename_playlist(guint plid, gchar *name, 
+guint32 jukebox_create_playlist(gchar *plname, GtkTreeStore *pltreestore);
+void jukebox_delete_playlist(guint32 plid);
+void jukebox_rename_playlist(guint32 plid, gchar *name, 
 			     GtkTreeStore *pltreestore);
 void add_tracks_to_playlists(GList *playlists, GList *metalist);
 void build_playlist_tree(GtkTreeStore *pltreestore);
 guint jukebox_randomize_playlist(guint playlist, GtkTreeStore *pltreestore);
-guint jukebox_delete_track_from_playlist(guint trackid, guint plist, GtkTreeStore *pltreestore);
+guint jukebox_delete_track_from_playlist(guint32 trackid, guint32 plist, GtkTreeStore *pltreestore);
 gchar *jukebox_get_ownerstring(void);
 void jukebox_set_ownerstring(gchar *owner);
-void jukebox_getusage(guint64 *total, guint64 *free, guint64 *used, 
-		      guint *songs, guint *playlists, guint *datafiles);
 gchar *jukebox_get_time(void);
 void jukebox_reset_get_eax(void);
 njb_eax_t *jukebox_get_eax(void);
