@@ -38,6 +38,7 @@ metadata_t *new_metadata_t()
   meta->filename = NULL;
   meta->path = NULL;
   meta->folder = NULL;
+  return meta;
 }
 
 void destroy_metadata_t(metadata_t *meta)
@@ -105,12 +106,12 @@ void dump_metadata_t(metadata_t const * const meta)
   g_print("Artist:    %s\n", metadata_string_escape(meta->artist));
   g_print("Title:     %s\n", metadata_string_escape(meta->title));
   g_print("Album:     %s\n", metadata_string_escape(meta->album));
-  g_print("Year:      %lu\n", meta->year);
+  g_print("Year:      %" PRIguint32 "\n", meta->year);
   g_print("Genre:     %s\n", metadata_string_escape(meta->genre));
   g_print("Length:    %s\n", metadata_string_escape(meta->length));
   g_print("Size:      %lu bytes\n", meta->size);
   g_print("Codec:     %s\n", metadata_string_escape(meta->codec));
-  g_print("Track#:    %lu\n", meta->trackno);
+  g_print("Track#:    %" PRIguint32 "\n", meta->trackno);
   g_print("Protected: %s\n", meta->protect ? "YES" : "NO");
   g_print("Filename:  %s\n", metadata_string_escape(meta->filename));
   g_print("Path:      %s\n", metadata_string_escape(meta->path));
@@ -193,14 +194,14 @@ gchar *compose_metadata_string(metadata_t const * const meta,
     returnname = replacestring(returnname, "%g", "<Unknown>");
   }
   // The following does not contain filesystem-illegal characters
-  tmptrackno = g_strdup_printf("%02lu", meta->trackno);
+  tmptrackno = g_strdup_printf("%02u", meta->trackno);
   if (tmptrackno) {
     returnname = replacestring(returnname, "%n", tmptrackno);
   } else {
     returnname = replacestring(returnname, "%n", "00");
   }
   g_free(tmptrackno);
-  tmpyear = g_strdup_printf("%lu", meta->year);
+  tmpyear = g_strdup_printf("%" PRIguint32, meta->year);
   if (tmpyear)
     returnname = replacestring(returnname, "%y", tmpyear);
   else
@@ -254,7 +255,7 @@ metadata_t *get_data_metadata_from_model(GtkTreeModel *model,
 void add_metadata_to_model(metadata_t const * const meta, 
 			   listtype_t const listtype)
 {
-  GtkListStore *liststore;
+  GtkListStore *liststore = NULL;  /* initialize to shut up GCC */
   GtkTreeIter listiter;
 
   if (listtype == HD_LIST || listtype == JB_LIST) {
@@ -914,8 +915,6 @@ void recreate_list_store(listtype_t listtype)
 void create_list_stores()
 {
   /* The list stores */
-  GtkListStore *hdliststore;
-  GtkListStore *hddataliststore;
   GtkTreeStore *pltreestore;
 
   pltreestore = gtk_tree_store_new(PLIST_N_COLUMNS,
