@@ -24,12 +24,12 @@ typedef struct
   gchar *artist;
   gchar *title;
   gchar *album;
-  guint year;
+  guint32 year;
   gchar *genre;
   gchar *length;
-  guint size;
+  gulong size;
   gchar *codec;
-  guint trackno;
+  guint32 trackno;
   gboolean protect;
   gchar *filename;
   gchar *path;
