@@ -19,6 +19,7 @@ Boston, MA 02111-1307, USA.
 #include "common.h"
 #include "player.h"
 #include "jukebox.h"
+#include "util.h"
 
 typedef struct {
   guint16 effect;
@@ -283,7 +284,6 @@ static GtkWidget *get_eax_controls()
   GtkWidget *label;
   GtkWidget *checkbox;
   GtkWidget *vbox;
-  GtkWidget *vscale;
   guint16 lastgroup = 0xFFFF;
 #define HORIZONTAL 0x00
 #define VERTICAL   0x01
@@ -433,9 +433,12 @@ void create_player_window(GList *metalist)
 {
   static play_thread_arg_t play_thread_args;
   GtkWidget *label1, *label2, *label3, *dialog, *button, *separator;
-  GtkWidget *label, *arrow;
   GtkWidget *hscale, *eax_controls;
-  GtkWidget *hbox, *hbox2, *hbox3, *vbox;
+  GtkWidget *hbox, *hbox2, *vbox;
+#if !GTK_CHECK_VERSION(2,6,0)
+  GtkWidget *label, *arrow;
+  GtkWidget *hbox3;
+#endif
   GtkAdjustment *adj;
 
   // Playback on MTP devices not supported. (Yet.)
