@@ -22,6 +22,7 @@ Boston, MA 02111-1307, USA.
 #include "player.h"
 #include "util.h"
 #include "prefs.h"
+#include "filesystem.h"
 
 #if !GTK_CHECK_VERSION(2,6,0)
 #include <libgnomeui/libgnomeui.h>
@@ -59,27 +60,27 @@ static gchar *get_text_from_selection_column(gint column)
   return text;
 }
 
-static guint get_playlistid_from_selection()
+static guint32 get_playlistid_from_selection()
 {
   gchar *text = NULL;
-  guint plid = 0;
+  guint32 plid = 0;
 
   text = get_text_from_selection_column(PLIST_PLID_COLUMN);
   if (text != NULL) {
-    plid = string_to_guint(text);
+    plid = string_to_guint32(text);
     g_free(text);
   }
   return plid;
 }
 
-static guint get_trackid_from_selection()
+static guint32 get_trackid_from_selection()
 {
   gchar *text = NULL;
-  guint trackid = 0;
+  guint32 trackid = 0;
 
   text = get_text_from_selection_column(PLIST_SONGID_COLUMN);
   if (text != NULL) {
-    trackid = string_to_guint(text);
+    trackid = string_to_guint32(text);
     g_free(text);
   }
   return trackid;
@@ -117,12 +118,12 @@ static gboolean foreach_renumber(GtkTreeModel *model,
 }
 
 /* Change playlist ID on all occurences in the list store */
-static void update_playlistid_in_store(guint old_plid, guint new_plid)
+static void update_playlistid_in_store(guint32 old_plid, guint32 new_plid)
 {
   gchar *swap[2];
 
-  swap[0] = g_strdup_printf("%lu", old_plid);
-  swap[1] = g_strdup_printf("%lu", new_plid);
+  swap[0] = g_strdup_printf("%" PRIguint32, old_plid);
+  swap[1] = g_strdup_printf("%" PRIguint32, new_plid);
   /* g_print("Trying to renumber playlist %s to %s...\n", swap[0], swap[1]); */
   gtk_tree_model_foreach(GTK_TREE_MODEL(playlist_widgets.pltreestore),
 			 (GtkTreeModelForeachFunc) foreach_renumber,
@@ -141,6 +142,7 @@ GCallback dispose_of_dialog_window(GtkButton * button, gpointer data)
 {
 	GtkWidget * tmpwid=GTK_WIDGET(data);
 	gtk_widget_destroy(tmpwid);
+	return NULL;
 }
 #endif
 
@@ -148,12 +150,13 @@ static GCallback create_new_playlist_ok_button (GtkButton *button,
 						gpointer data)
 {
   gchar *plname;
-  guint plid;
+  guint32 plid;
 
   plname = g_strdup(gtk_entry_get_text(GTK_ENTRY(new_pl_entry)));
   gtk_widget_destroy(new_pl_dialog);
   plid = jukebox_create_playlist(plname, playlist_widgets.pltreestore);
   g_free(plname);
+  return NULL;
 }
 
 
@@ -213,23 +216,23 @@ static GCallback playlist_new_response(gpointer data)
 		   G_OBJECT (new_pl_dialog));
 
   gtk_widget_show_all(new_pl_dialog);
+  return NULL;
 }
 
 /* Response to the Play playlist popup menu function */
 static GCallback playlist_play_response(gpointer data)
 {
-  GtkTreeSelection *selection;
-  GtkTreeIter iter;
-  guint plid;
+  guint32 plid;
   
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
-    return;
+    return NULL;
   }
   /* Get the ID of the playlist */
   plid = get_playlistid_from_selection();
   if (plid > 0)
     play_playlist(plid);
+  return NULL;
 }
 
 static GCallback edit_playlist_ok_button (GtkButton *button,
@@ -240,7 +243,7 @@ static GCallback edit_playlist_ok_button (GtkButton *button,
 
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
-    return;
+    return NULL;
   }
 
   plid = get_playlistid_from_selection();
@@ -249,6 +252,7 @@ static GCallback edit_playlist_ok_button (GtkButton *button,
   gtk_widget_destroy(edit_pl_dialog);
 
   g_free(plname);
+  return NULL;
 }
 
 /* Response to the Edit playlist popup menu function */
@@ -256,9 +260,7 @@ static GCallback playlist_edit_response(gpointer data)
 {
   GtkWidget *label, *button;
   gchar *text;
-  guint8 dummy1;
-  GdkPixmap *dummy2;
-  gboolean dummy3;
+
 #if !GTK_CHECK_VERSION(2,6,0)
   edit_pl_dialog = gnome_dialog_new(_("Edit playlist"),
 				    GNOME_STOCK_BUTTON_CANCEL,
@@ -315,6 +317,7 @@ static GCallback playlist_edit_response(gpointer data)
 			  GTK_OBJECT (edit_pl_dialog),
 			  0);
   gtk_widget_show_all(edit_pl_dialog);
+  return NULL;
 }
 
 static void toggle_m3ulist (GtkCheckButton *toggle,
@@ -423,7 +426,6 @@ static void toggle_plslist (GtkCheckButton *toggle,
 static GCallback export_playlist_ok_button (GtkButton *button,
 				     gpointer data)
 {
-  guint plid;
   gchar *filename;
   gchar *formatstring;
   GList *playlist = (GList *) data;
@@ -439,18 +441,17 @@ static GCallback export_playlist_ok_button (GtkButton *button,
   destroy_metalist(playlist);
   g_free(filename);
   g_free(formatstring);
+  return NULL;
 }
 
 /* Response to the Export playlist popup menu function */
 static GCallback playlist_export_response(gpointer data)
 {
-  GtkTreeSelection *selection;
-  GtkTreeIter iter;
   guint plid;
   
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
-    return;
+    return NULL;
   }
   /* Get the ID of the playlist */
   plid = get_playlistid_from_selection();
@@ -560,6 +561,7 @@ static GCallback playlist_export_response(gpointer data)
       gtk_widget_show_all(export_pl_dialog);
     }
   }
+  return NULL;
 }
 
 /* Response to the Delete playlist popup menu function */
@@ -569,7 +571,7 @@ static GCallback playlist_delete_response(gpointer data)
 
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
-    return;
+    return NULL;
   }
   plid = get_playlistid_from_selection();
   if (plid) {
@@ -579,6 +581,7 @@ static GCallback playlist_delete_response(gpointer data)
 	remove_selected_row();
       }
     }
+  return NULL;
 }
 
 /* Response to the Shuffle playlist popup menu function */
@@ -589,25 +592,24 @@ static GCallback playlist_shuffle_response(gpointer data)
 
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
-    return;
+    return NULL;
   }
   plid = get_playlistid_from_selection();
   newplaylist = jukebox_randomize_playlist(plid, playlist_widgets.pltreestore);
   /* g_print("Shuffeling playlist %lu...\n", plid); */
+  return NULL;
 }
 
 /* Response to the Delete track popup menu function */
 static GCallback node_delete_response(gpointer data)
 {
-  guint plid;
-  guint track;
-  guint newplaylist;
-
-  gint i;
+  guint32 plid;
+  guint32 track;
+  guint32 newplaylist;
 
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
-    return;
+    return NULL;
   }
 
   if (request_confirmation_dialog(_("Really delete selected tracks?"))) {
@@ -620,6 +622,7 @@ static GCallback node_delete_response(gpointer data)
     // This should work now.
     update_playlistid_in_store(plid, newplaylist);
   }
+  return NULL;
 }
 
 
@@ -687,13 +690,13 @@ static GCallback toggle_and(gpointer a, gpointer b)
 {
   GtkToggleButton *tbutton = GTK_TOGGLE_BUTTON(a);
   guint next = GPOINTER_TO_UINT(b)+1;
-  gboolean active = gtk_toggle_button_get_active(tbutton);
 
   /* Force the toggle button to active and grey it out */
   gtk_toggle_button_set_active(tbutton, TRUE);
   gtk_widget_set_sensitive(GTK_WIDGET(tbutton), FALSE);
   /* If this was not previously selected, it's time to create a new one */
   add_pl_selection(GTK_BOX(GNOME_DIALOG(select_playlist_dialog)->vbox), next);
+  return NULL;
 }
 
 /*
@@ -804,9 +807,7 @@ static void add_to_playlist_ok_button (GtkButton *button,
 				       gpointer data)
 {
   GList *metalist = get_all_metadata_from_selection(JB_LIST);
-  GList *templist;
   GList *listlist = get_selected_playlists(); /* Playlists to add these to. */
-  GSList *songidlist = NULL;
 
   /* If no songs were selected, abort this */
   if (!metalist) {
@@ -848,6 +849,7 @@ static GCallback transfer_from_hd_ok_button (GtkButton *button,
   gtk_widget_destroy(select_playlist_dialog);
   /* Set it as argument */
   transfer_from_hd_to_jukebox(listlist);
+  return NULL;
 }
 
 void transfer_from_hd_dialog (GtkButton *inbutton,
@@ -873,8 +875,6 @@ void jbmenu_add_playlist_response(gpointer data)
 static GtkWidget *create_treeview(GtkTreeStore *treestore)
 {
   GtkWidget *treeview;
-  GtkTreeIter treeiter;
-  GtkTreeIter treeiter2;
   GtkCellRenderer *textrenderer;
   GtkTreeViewColumn *view;
   GtkTreeSelection *select;
@@ -973,7 +973,7 @@ static GtkWidget *create_treeview(GtkTreeStore *treestore)
 void create_playlist_widgets(GtkWidget *box)
 {
   GtkWidget *scrolled_window, *pltreeview, *playlistpopupmenu,
-    *blankpopupmenu, *nodepopupmenu, *playlist_item, *popupmenu_item;
+    *blankpopupmenu, *nodepopupmenu, *popupmenu_item;
   
   selected_target_playlists = NULL;
 
