@@ -40,7 +40,10 @@ static GtkWidget *set_time = NULL;
 static GtkWidget *remember_dir = NULL;
 static GtkWidget *turbo_mode = NULL;
 
-static void read_prefs_file()
+static gboolean get_prefs_remember_dir(void);
+
+
+static void read_prefs_file(void)
 {
   const gchar scannername[] = PACKAGE " lexical scanner";
   GScanner *scanner;
@@ -177,7 +180,7 @@ static void read_prefs_file()
   close_prefsfile();
 }
 
-void write_prefs_file()
+void write_prefs_file(void)
 {
   gchar *prefs = NULL;
   gchar *fnameformat = NULL;
@@ -292,7 +295,7 @@ void write_prefs_file()
   rewrite_prefsfile(prefs);
 }
 
-gboolean get_prefs_use_origname()
+gboolean get_prefs_use_origname(void)
 {
   if (use_origname == NULL)
     return FALSE;
@@ -300,7 +303,7 @@ gboolean get_prefs_use_origname()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(use_origname));
 }
 
-gboolean get_prefs_id3override()
+gboolean get_prefs_id3override(void)
 {
   if (id3override == NULL)
     return FALSE;
@@ -308,7 +311,7 @@ gboolean get_prefs_id3override()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(id3override));
 }
 
-gboolean get_prefs_id3remove()
+gboolean get_prefs_id3remove(void)
 {
   if (id3remove == NULL)
     return FALSE;
@@ -316,7 +319,7 @@ gboolean get_prefs_id3remove()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(id3remove));
 }
 
-gboolean get_prefs_useid3()
+gboolean get_prefs_useid3(void)
 {
   if (useid3 == NULL)
     return FALSE;
@@ -324,7 +327,7 @@ gboolean get_prefs_useid3()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(useid3));
 }
 
-gboolean get_prefs_useid3_unicode()
+gboolean get_prefs_useid3_unicode(void)
 {
   if (useid3_unicode == NULL)
     return FALSE;
@@ -332,7 +335,7 @@ gboolean get_prefs_useid3_unicode()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(useid3_unicode));
 }
 
-gboolean get_prefs_display_dotdirs()
+gboolean get_prefs_display_dotdirs(void)
 {
   if (display_dotdirs == NULL)
     return FALSE;
@@ -340,7 +343,7 @@ gboolean get_prefs_display_dotdirs()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(display_dotdirs));
 }
 
-gboolean get_prefs_ask_playlist()
+gboolean get_prefs_ask_playlist(void)
 {
   if (ask_playlist == NULL)
     return FALSE;
@@ -348,7 +351,7 @@ gboolean get_prefs_ask_playlist()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ask_playlist));
 }
 
-gboolean get_prefs_recurse_dir()
+gboolean get_prefs_recurse_dir(void)
 {
   if (recurse_dir == NULL)
     return FALSE;
@@ -357,7 +360,7 @@ gboolean get_prefs_recurse_dir()
 }
 
 #ifndef G_OS_WIN32
-gboolean get_prefs_force_8859()
+gboolean get_prefs_force_8859(void)
 {
   if (force_8859 == NULL)
     return FALSE;
@@ -366,7 +369,7 @@ gboolean get_prefs_force_8859()
 }
 #endif
 
-gboolean get_prefs_detect_metadata()
+gboolean get_prefs_detect_metadata(void)
 {
   if (detect_metadata == NULL)
     return FALSE;
@@ -374,7 +377,7 @@ gboolean get_prefs_detect_metadata()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(detect_metadata));
 }
 
-gboolean get_prefs_extended_metadata()
+gboolean get_prefs_extended_metadata(void)
 {
   if (extended_metadata == NULL)
     return FALSE;
@@ -382,7 +385,7 @@ gboolean get_prefs_extended_metadata()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(extended_metadata));
 }
 
-gboolean get_prefs_autoscan()
+gboolean get_prefs_autoscan(void)
 {
   if (autoscan == NULL)
     return FALSE;
@@ -390,7 +393,7 @@ gboolean get_prefs_autoscan()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(autoscan));
 }
 
-gboolean get_prefs_set_time()
+gboolean get_prefs_set_time(void)
 {
   if (set_time == NULL)
     return FALSE;
@@ -398,7 +401,7 @@ gboolean get_prefs_set_time()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(set_time));
 }
 
-gboolean get_prefs_remember_dir()
+static gboolean get_prefs_remember_dir(void)
 {
   if (remember_dir == NULL)
     return FALSE;
@@ -406,7 +409,7 @@ gboolean get_prefs_remember_dir()
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(remember_dir));
 }
 
-gboolean get_prefs_turbo_mode()
+gboolean get_prefs_turbo_mode(void)
 {
   if (turbo_mode == NULL)
     return FALSE;
@@ -415,7 +418,7 @@ gboolean get_prefs_turbo_mode()
 }
 
 
-gchar *get_prefs_filenameformat()
+gchar *get_prefs_filenameformat(void)
 {
   static gchar defaultformat[] = "%a - %t";
   G_CONST_RETURN gchar *returnformat;
@@ -447,8 +450,7 @@ static void toggle_extended_metadata (GtkCheckButton *toggle,
 void create_prefs_widgets(GtkWidget *box)
 {
   GtkWidget *hbox, *vbox, *vbox_naming,
-    *cb, *frame, *label;
-  gint i;
+    *frame, *label;
 
   /* Pack all prefs into a vbox */
   vbox = gtk_vbox_new(FALSE, 0);
