@@ -20,6 +20,9 @@ Boston, MA 02111-1307, USA.
 #ifndef PREFSH_INCLUDED
 #define PREFSH_INCLUDED 1
 
+/* Get windows indicator macro */
+#include <gtk/gtk.h>
+
 /* Exported functions */
 void write_prefs_file();
 gboolean get_prefs_id3override();
@@ -29,12 +32,15 @@ gboolean get_prefs_useid3_unicode();
 gboolean get_prefs_display_dotdirs();
 gboolean get_prefs_ask_playlist();
 gboolean get_prefs_recurse_dir();
+#ifndef G_OS_WIN32
 gboolean get_prefs_force_8859();
+#endif
 gboolean get_prefs_detect_metadata();
 gboolean get_prefs_extended_metadata();
 gboolean get_prefs_use_origname();
 gboolean get_prefs_autoscan();
 gboolean get_prefs_set_time();
+gboolean get_prefs_turbo_mode();
 gchar *get_prefs_filenameformat();
 void create_prefs_widgets(GtkWidget *box);
 
