@@ -28,6 +28,10 @@ scratch.
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#if GLIB_CHECK_VERSION(2,6,0)
+#   include <glib.h>
+#   include <glib/gstdio.h>
+#endif
 
 static guint32 le_to_guint(guchar *data)
 {
@@ -78,7 +82,7 @@ get_tag_for_wavfile (metadata_t *meta)
       // This is indeed a RIFF/WAVE file
       guint32 chunksize = le_to_guint(&header[4]);
       guint32 fmtchunksize = le_to_guint(&header[16]);
-      guint32 samplerate = le_to_guint(&header[24]);
+      //guint32 samplerate = le_to_guint(&header[24]);
       guint32 byterate = le_to_guint(&header[28]);
       guint32 calctime;
 
