@@ -123,7 +123,6 @@ static GList *get_files_to_xfer(GList *metalist, GList *appendum) {
 	 && strcmp(meta->artist,"..") 
 	 && strcmp(meta->artist,".") ) {
 	GList *inner_metalist;
-	GList *tmp;
 
 	/* g_print("Recursing directory...\n"); */
 	/* Get metalist for directory */
@@ -147,7 +146,6 @@ static GList *get_files_to_xfer(GList *metalist, GList *appendum) {
 void transfer_from_hd_to_jukebox(GList *playlists)
 {
   GList *metalist = get_all_metadata_from_selection(HD_LIST);
-  GList *templist;
   GList *xferlist;
 
   if (jukebox_locked) {
@@ -210,15 +208,18 @@ void transfer_from_hd_to_jukebox(GList *playlists)
 
     /* Dumps the xfer list without transferring anything - for debugging */
     /*
-    g_print("Transferring...\n");
-    templist = g_list_first(xferlist);
-    while (templist) {
-      metadata_t *meta = (metadata_t *) templist->data;
-      g_print("To transfer: %s\n", meta->path);
-      templist = g_list_next(templist);
+    {
+      GList *templist = g_list_first(xferlist);
+
+      g_print("Transferring...\n");
+      while (templist) {
+        metadata_t *meta = (metadata_t *) templist->data;
+        g_print("To transfer: %s\n", meta->path);
+        templist = g_list_next(templist);
+      }
+      destroy_metalist(xferlist);
+      gtk_widget_destroy(dialog);
     }
-    destroy_metalist(xferlist);
-    gtk_widget_destroy(dialog);
     */
     jukebox_locked = TRUE;
     cancel_jukebox_operation = FALSE;
@@ -260,6 +261,7 @@ static void add_to_history (gchar *string)
 static GCallback hdmenu_rescan_response(gpointer data)
 {
   fill_in_dir(HD_LIST, get_current_dir());
+  return NULL;
 }
 
 
@@ -267,6 +269,7 @@ static GCallback hdmenu_rescan_response(gpointer data)
 static GCallback hdmenu_transfer_response(gpointer data)
 {
   transfer_from_hd_dialog(NULL, NULL);
+  return NULL;
 }
 
 
@@ -282,6 +285,7 @@ static GCallback hdmenu_delete_response(gpointer data)
     else fill_in_dir(HD_LIST, get_current_dir());
     destroy_metalist(metalist);
   }
+  return NULL;
 }
 
 static GCallback create_new_folder_ok_button (GtkButton *button,
@@ -296,13 +300,22 @@ static GCallback create_new_folder_ok_button (GtkButton *button,
 
   fullpath = g_strconcat(current,"/",foldername,NULL);
 
-  if(g_mkdir_with_parents(fullpath,0755)) create_error_dialog(_("Could not create folder"));
+#if !GTK_CHECK_VERSION(2,8,0)
+  if (g_mkdir(fullpath,0755)) {
+	  create_error_dialog(_("Could not create folder"));
+  }
+#else
+  if (g_mkdir_with_parents(fullpath,0755)) {
+	  create_error_dialog(_("Could not create folder"));
+  }
+#endif
 
   fill_in_dir(HD_LIST, get_current_dir());
 
   g_free(fullpath);
   g_free(current);
   g_free(foldername);
+  return NULL;
 }
 
 /* Response to the "new folder..." call from the harddisk popup menu */
@@ -310,6 +323,7 @@ static GCallback hdmenu_new_folder_response(gpointer data)
 {
   GtkWidget *label, *button;
 #if !GTK_CHECK_VERSION(2,6,0)  
+  // Here we use libgnomeui instead.
   new_folder_dialog = gnome_dialog_new(_("New folder"),
 				   GNOME_STOCK_BUTTON_CANCEL,
 				   GNOME_STOCK_BUTTON_OK,
@@ -361,6 +375,7 @@ static GCallback hdmenu_new_folder_response(gpointer data)
 		   G_OBJECT (new_folder_dialog));
 
   gtk_widget_show_all(new_folder_dialog);
+  return NULL;
 }
 
 /* Handles descending into a directory in the clist */
@@ -431,6 +446,7 @@ static GCallback hdlist_keyevent (GtkWidget    *widget,
 static GCallback jbmenu_rescan_response(gpointer data)
 {
   scan_jukebox(NULL);
+  return NULL;
 }
 
 
@@ -438,6 +454,7 @@ static GCallback jbmenu_rescan_response(gpointer data)
 static GCallback jbmenu_transfer_response(gpointer data)
 {
   transfer_from_jukebox_to_hd(NULL, NULL);
+  return NULL;
 }
 
 /* Response to a request to play some music */
@@ -446,13 +463,14 @@ static GCallback jbmenu_play_response(gpointer data)
   GList *metalist = get_all_metadata_from_selection(JB_LIST);
 
   if (metalist == NULL)
-    return;
+    return NULL;
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
     destroy_metalist(metalist);
-    return;
+    return NULL;
   }
   create_player_window(metalist);
+  return NULL;
 }
 
 
@@ -466,6 +484,7 @@ static GCallback jbmenu_delete_response(gpointer data)
     remove_selected(JB_LIST);
     destroy_metalist(metalist);
   }
+  return NULL;
 }
 
 static GCallback jblist_mouseevent (GtkWidget      *clist,
@@ -515,13 +534,13 @@ static void cell_data_func (GtkTreeViewColumn *tree_column,
   metadata_t *meta = get_metadata_from_model(model, iter);
   if (meta->size == 0) {
     g_object_set(G_OBJECT(cell),
-		 "foreground", "blue", 
+		 "foreground", GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR, 
 		 "weight", "bold",
 		 "underline", TRUE,
 		 NULL);
   } else {
     g_object_set(G_OBJECT(cell),
-		 "foreground", "black", 
+		 "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
 		 "weight", NULL,
 		 "underline", FALSE,
 		 NULL);
@@ -532,7 +551,6 @@ static void cell_data_func (GtkTreeViewColumn *tree_column,
 static GtkWidget *create_listview(GtkListStore *liststore)
 {
   GtkWidget *listview;
-  GtkTreeIter listiter;
   GtkCellRenderer *dirtextrenderer;
   GtkCellRenderer *textrenderer;
   GtkCellRenderer *timerenderer;
@@ -540,6 +558,8 @@ static GtkWidget *create_listview(GtkListStore *liststore)
   GtkTreeViewColumn *view;
 
   /* For testing to add something to the store.
+    GtkTreeIter listiter;
+
     gtk_list_store_append (GTK_LIST_STORE(liststore), &listiter);
     gtk_list_store_set (GTK_LIST_STORE(liststore), &listiter,
     TRACKLIST_ARTIST_COLUMN, "Artist",
@@ -724,7 +744,6 @@ GtkWidget *create_xfer_widgets()
 {
   GtkWidget *popupmenu, *popupmenu_item;
   GtkWidget *button;
-  GtkWidget *vbox, *hbox;
   GtkWidget *leftbox;
   GtkWidget *music_panel;
   GtkWidget *transfer_button_vbox;
@@ -739,8 +758,6 @@ GtkWidget *create_xfer_widgets()
   GtkTreeSelection *hdlistselection;
   GtkTreeSelection *jblistselection;
   GtkWidget *label;
-  gint i;
-  GConnectFlags connFlags;
 
   transfer_widgets.history = NULL;
   /* Just add something to the history... */
